dnl matlab.m4 --- check for Matlab.
dnl
dnl Copyright (C) 2000--2002 Ralph Schleicher
dnl
dnl Author: Ralph Schleicher <rs@nunatak.allgaeu.org>
dnl Version: $Id$
dnl
dnl This program is free software; you can redistribute it and/or
dnl modify it under the terms of the GNU General Public License as
dnl published by the Free Software Foundation; either version 2,
dnl or (at your option) any later version.
dnl
dnl This program is distributed in the hope that it will be useful,
dnl but WITHOUT ANY WARRANTY; without even the implied warranty of
dnl MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
dnl GNU General Public License for more details.
dnl
dnl You should have received a copy of the GNU General Public License
dnl along with this program; see the file COPYING.  If not, write to
dnl the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
dnl Boston, MA 02111-1307, USA.
dnl
dnl As a special exception to the GNU General Public License, if
dnl you distribute this file as part of a program that contains a
dnl configuration script generated by GNU Autoconf, you may include
dnl it under the same distribution terms that you use for the rest
dnl of that program.
dnl
dnl Code:

# MX_MATLAB
# ---------
# Check for Matlab.
AC_DEFUN([MX_MATLAB],
[dnl
AC_PREREQ([2.50])
# Top-level Matlab installation directory.
mx_matlab_prefix="$MATLAB"
# Canonical name of Matlab program.
mx_matlab_program=
# Matlab conditional.
mx_enable_matlab=
AC_ARG_WITH([matlab],
	    AC_HELP_STRING([--with-matlab@<:@=ARG@:>@],
			   [check for Matlab @<:@yes@:>@]),
	    [case $withval in
	      yes | no)
		# Explicitly enable or disable Matlab, but determine
		# Matlab prefix automatically.
		mx_enable_matlab=$withval
		;;
	      *)
		# Enable Matlab and use ARG as the Matlab prefix.
		# ARG must be an existing directory.
		mx_enable_matlab=yes
		mx_matlab_prefix=`cd "${withval-/}" 2> /dev/null && pwd`
		if test "x$mx_matlab_prefix" = x ; then
		    AC_MSG_ERROR([invalid value \`$withval' for --with-matlab])
		fi
		;;
	    esac])
AC_MSG_CHECKING([for matlab])
mx_dir=`echo "$mx_matlab_prefix" | sed 's,/*$,/bin,'`
mx_path="$mx_dir:${PATH-/usr/local/bin:/usr/bin:/bin}"
IFS="${IFS= 	}" ; mx_ifs="$IFS" ; IFS=:
for mx_dir in $mx_path ; do
    if test "x$mx_dir" = x ; then
	mx_dir=.
    fi
    mx_dir=`cd "$mx_dir" 2> /dev/null && pwd`
    if test "x$mx_dir" != x && test -x "$mx_dir/matlab" ; then
	mx_matlab_program="$mx_dir/matlab"
	break
    fi
done
IFS="$mx_ifs"
AC_MSG_RESULT([$mx_matlab_program])
AC_MSG_CHECKING([for Matlab prefix])
if test "x$mx_matlab_prefix" != x ; then
    # mx_matlab_prefix was set via MATLAB environment variable or via
    # argument of --with-matlab option.  Strip trailing dashes.
    mx_matlab_prefix=`echo "$mx_matlab_prefix" | sed 's,/*$,,'`
elif test "${MATLAB+set}" != set ; then
    # Guess Matlab prefix from the program name.
    mx_matlab_prefix=`echo "$mx_matlab_program" | sed 's,/bin/matlab$,,'`
fi
AC_MSG_RESULT([$mx_matlab_prefix])
AC_MSG_CHECKING([whether to enable Matlab support])
if test x$mx_enable_matlab != xno ; then
    if test -d "$mx_matlab_prefix/toolbox/matlab" ; then
	mx_enable_matlab=yes
    elif test x$mx_enable_matlab = x ; then
	mx_enable_matlab=no
    else
	# Fail if Matlab was explicitly enabled.
	AC_MSG_RESULT([failure])
	AC_MSG_ERROR([check your Matlab setup])
    fi
fi
AC_MSG_RESULT([$mx_enable_matlab])
if test x$mx_enable_matlab = xyes ; then
    AC_DEFINE([HAVE_MATLAB])
fi
MATLAB="$mx_matlab_prefix"
AC_SUBST([MATLAB])
])

# MX_MATLAB_CONDITIONAL
# ---------------------
# Define Matlab conditional for GNU Automake.
AC_DEFUN([MX_MATLAB_CONDITIONAL],
[dnl
AC_PREREQ([2.50])
AC_REQUIRE([MX_MATLAB])
AM_CONDITIONAL([MATLAB], [test x$mx_enable_matlab = xyes])
])

dnl matlab.m4 ends here
